lists.ListType (List Type) — amici1

# `lists.ListType` (List Type)

Represents a possible choice for the list_type field of a

  `List`.

Master tables : lists.ListTypes (List Types)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Designation (designation) : See `<lino.utils.mldbc.fields.BabelCharField: designation>`.

- Designation (de) (designation_de) : See `<django.db.models.fields.CharField: designation_de>`.

- Designation (fr) (designation_fr) : See `<django.db.models.fields.CharField: designation_fr>`.

- Name (name_column) : See `lino_xl.lib.lists.models.ListType.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.lists.models.ListType.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.lists.models.ListType.overview`.

Referenced from lists.List.list_type

## Database fields

Internal name | Verbose name | Help text
id | ID |
designation | Designation |
designation_de | Designation (de) |
designation_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |